require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xscvmmconsolesetup',
  dscmeta_resource_friendly_name: 'xSCVMMConsoleSetup',
  dscmeta_resource_name: 'MSFT_xSCVMMConsoleSetup',
  dscmeta_module_name: 'xSCVMM',
  dscmeta_module_version: '1.2.4.0',
  docs: 'The DSC xSCVMMConsoleSetup resource type.
         Automatically generated from version 1.2.4.0',
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_sourcepath: {
      type: 'String',
      desc: 'UNC path to the root of the source files for installation.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_muoptin: {
      type: 'Optional[Hash]',
      desc: '0: Do not opt in to Microsoft Update. 1: Opt in to Microsoft Update.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt8',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_ensure: {
      type: "Enum['Present', 'Absent']",
      desc: 'An enumerated value that describes if the DPM server is expected to be installed on the machine. Present {default}   Absent    ',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_indigotcpport: {
      type: 'Optional[Integer[0, 65535]]',
      desc: 'Port for communication with the VMM management server.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt16',
      mof_is_embedded: false,
    },
    dsc_setupcredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credential to be used to perform the installation.',
      behaviour: :parameter,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_programfiles: {
      type: 'Optional[String]',
      desc: 'Installation path for the software.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sourcefolder: {
      type: 'Optional[String]',
      desc: 'Folder within the source path containing the source files for installation.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
