require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xscvmmmanagementserversetup',
  dscmeta_resource_friendly_name: 'xSCVMMManagementServerSetup',
  dscmeta_resource_name: 'MSFT_xSCVMMManagementServerSetup',
  dscmeta_module_name: 'xSCVMM',
  dscmeta_module_version: '1.2.4.0',
  docs: 'The DSC xSCVMMManagementServerSetup resource type.
         Automatically generated from version 1.2.4.0',
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_retainsqldatabase: {
      type: 'Optional[Hash]',
      desc: '0: Remove the SQL Server database. 1: Do not remove the SQL Server database.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt8',
      mof_is_embedded: false,
    },
    dsc_vmmservername: {
      type: 'Optional[String]',
      desc: 'Clustered service name for a highly available VMM management server.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_vmmservice: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Domain account for the VMM service.',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_username: {
      type: 'Optional[String]',
      desc: 'Display name for the user.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_wsmantcpport: {
      type: 'Optional[Integer[0, 65535]]',
      desc: 'Port for communication with agents on hosts and library servers.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt16',
      mof_is_embedded: false,
    },
    dsc_productkey: {
      type: 'Optional[String]',
      desc: 'Product key for licensed installations.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_muoptin: {
      type: 'Optional[Hash]',
      desc: '0: Do not opt in to Microsoft Update. 1: Opt in to Microsoft Update.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt8',
      mof_is_embedded: false,
    },
    dsc_indigohttpport: {
      type: 'Optional[Integer[0, 65535]]',
      desc: 'Port for communication with Windows PE agent for time synchronization.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt16',
      mof_is_embedded: false,
    },
    dsc_setupcredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credential to be used to perform the installation.',
      behaviour: :parameter,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_indigonettcpport: {
      type: 'Optional[Integer[0, 65535]]',
      desc: 'Port for communication with Windows Deployment Services.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt16',
      mof_is_embedded: false,
    },
    dsc_sqmoptin: {
      type: 'Optional[Hash]',
      desc: '0: Do not opt in to the Customer Experience Improvement Program (CEIP). 1: Opt in to CEIP.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt8',
      mof_is_embedded: false,
    },
    dsc_librarysharepath: {
      type: 'Optional[String]',
      desc: 'Location of the existing file share or the new file share to be created.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_librarysharedescription: {
      type: 'Optional[String]',
      desc: 'Description of the share.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sourcefolder: {
      type: 'Optional[String]',
      desc: 'Folder within the source path containing the source files for installation.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_bitstcpport: {
      type: 'Optional[Integer[0, 65535]]',
      desc: 'Port for file transfers to agents on hosts and library servers.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt16',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_createnewlibraryshare: {
      type: 'Optional[String]',
      desc: '0: Use an existing library share. 1: Create a new library share.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_librarysharename: {
      type: 'Optional[String]',
      desc: 'Name of the file share to be used or created.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sqlmachinename: {
      type: 'String',
      desc: 'Name of the server that is hosting SQL Server.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_programfiles: {
      type: 'Optional[String]',
      desc: 'Installation path for the software.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_indigotcpport: {
      type: 'Optional[Integer[0, 65535]]',
      desc: 'Port for communication with the VMM console.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt16',
      mof_is_embedded: false,
    },
    dsc_createnewsqldatabase: {
      type: 'Optional[String]',
      desc: '0: Use an existing Microsoft SQL Server database. 1: Create a new SQL Server database.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_topcontainername: {
      type: 'Optional[String]',
      desc: 'Container for Distributed Key Management.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_forcehavmmuninstall: {
      type: 'Optional[Hash]',
      desc: '0: Do not force uninstallation if setup.exe cannot verify whether this node is the final node of the highly available installation. 1: Force the uninstallation.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt8',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Enum['Present', 'Absent']",
      desc: 'An enumerated value that describes if the DPM server is expected to be installed on the machine. Present {default}   Absent    ',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sqlinstancename: {
      type: 'String',
      desc: 'Name of the new or existing instance of SQL Server.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sqldatabasename: {
      type: 'Optional[String]',
      desc: 'Name of the new or existing SQL Server database.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sourcepath: {
      type: 'String',
      desc: 'UNC path to the root of the source files for installation.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_indigohttpsport: {
      type: 'Optional[Integer[0, 65535]]',
      desc: 'Port for communication with the Windows Preinstallation Environment agents.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt16',
      mof_is_embedded: false,
    },
    dsc_companyname: {
      type: 'Optional[String]',
      desc: 'Display name for the organization.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_clustermanagementserver: {
      type: 'Optional[Boolean]',
      desc: 'Is this a clustered Management Server?',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_firstmanagementserver: {
      type: 'Optional[Boolean]',
      desc: 'Is this the first Management Server?',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_vmmserviceusername: {
      type: 'Optional[String]',
      desc: 'Output username of the VMM service.',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_vmmstaticipaddress: {
      type: 'Optional[String]',
      desc: 'IP address for the clustered service name for a highly available VMM management server, if you are not using Dynamic Host Configuration Protocol (DHCP).',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
