require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xscvmmoperationsmanagerserver',
  dscmeta_resource_friendly_name: 'xSCVMMOperationsManagerServer',
  dscmeta_resource_name: 'MSFT_xSCVMMOperationsManagerServer',
  dscmeta_module_name: 'xSCVMM',
  dscmeta_module_version: '1.2.4.0',
  docs: 'The DSC xSCVMMOperationsManagerServer resource type.
         Automatically generated from version 1.2.4.0',
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_vmmservercredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Specifies the credentials that Operations Manager uses to connect with VMM.',
      behaviour: :parameter,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_enablemaintenancemodeintegration: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether maintenance mode integration is enabled for this connection.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_enablepro: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether PRO is enabled for this connection.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_usevmmserverserviceaccount: {
      type: 'Optional[Boolean]',
      desc: 'Specifies the service account that VMM uses to connect to Operations Manager.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_scvmmadmincredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credential to be used to perform the operations.',
      behaviour: :parameter,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_opsmgrserver: {
      type: 'String',
      desc: 'Specifies the fully qualified domain name (FQDN) of the System Center Operations Manager management server to which VMM connects.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_opsmgrservercredential: {
      type: 'Optional[String]',
      desc: 'Specifies the name of the VMM RunAs account that VMM uses to connect to the Operations Manager management group.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Enum['Present', 'Absent']",
      desc: 'An enumerated value that describes if the Operations Manager connection exists. Present {default}   Absent    ',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
